/*
 * Programming in Java, Jacobs University, 2015
 *
 * Java uses introspection to work with beans. It is possible to
 * provide further information about a bean in case deviations from
 * the conventions are necessary or additional information about the
 * bean is useful (e.g., providing an icon for use in a graphical
 * programming environment).
 */

import java.beans.PropertyDescriptor;
import java.beans.EventSetDescriptor;
import java.beans.SimpleBeanInfo;
import java.beans.IntrospectionException;
import java.beans.PropertyChangeListener;
import java.beans.VetoableChangeListener;

public class VetoableBeanBeanInfo extends SimpleBeanInfo
{
    private static PropertyDescriptor[] properties;
    private static EventSetDescriptor[] events;
    
    static {
        try {
            PropertyDescriptor price 
                = new PropertyDescriptor("price", VetoableBean.class,
                                         "getPrice", "setPrice");
            properties = new PropertyDescriptor[] { price };

        } catch (IntrospectionException e) {
            e.printStackTrace();
        }

        try {
            EventSetDescriptor pce
                = new EventSetDescriptor(VetoableBean.class,
                                "propertyChange",
                                PropertyChangeListener.class,
                                new String[] { "propertyChanged" }, 
                                "addPropertyChangeListener", 
                                "removePropertyChangeListener");
            EventSetDescriptor vce
                = new EventSetDescriptor(VetoableBean.class,
                                "vetoableChange",
                                VetoableChangeListener.class,
                                new String[] { "vetoableChange" }, 
                                "addVetoableChangeListener", 
                                "removeVetoableChangeListener");
            events = new EventSetDescriptor[] { pce, vce };
        } catch (IntrospectionException e) {
            e.printStackTrace();
        }
    }

    public PropertyDescriptor[] getPropertyDescriptors()
    {
        return properties;
    }
    
    public EventSetDescriptor[] getEventSetDescriptors()
    {
        return events;
    }

    public java.awt.Image getIcon(int iconKind)
    {
        java.awt.Image img = null;
        if (iconKind == ICON_COLOR_16x16 || iconKind == ICON_MONO_16x16) {
            img = loadImage("price16.gif");
        }
        if (iconKind == ICON_COLOR_32x32 || iconKind == ICON_MONO_32x32) {
            img = loadImage("price32.gif");
        }
        return img;
    }
}
